Struct JitEvm
pub struct JitEvm<EVM, F = fn(FixedBytes<32>, &[u8]) -> Option<EvmCompilerFn>> {
inner: EVM,
functions: HashMap<FixedBytes<32>, unsafe extern "C" fn(NonNull<EvmContext<'_>>, NonNull<EvmStack>, NonNull<usize>) -> InstructionResult, FbBuildHasher<32>>,
on_miss: F,
}Expand description
Wrapper around any [EvmTr] that overrides [EvmTr::frame_run] to dispatch
to JIT-compiled functions by code hash, falling back to the interpreter.
The F parameter is a lookup function (B256, &[u8]) -> Option<EvmCompilerFn> called
when a code hash is not found in the precompiled map. Return None to fall
back to the interpreter; return Some(f) to execute f (e.g. compile on the fly).
Fields
inner: EVMfunctions: HashMap<FixedBytes<32>, unsafe extern "C" fn(NonNull<EvmContext<'_>>, NonNull<EvmStack>, NonNull<usize>) -> InstructionResult, FbBuildHasher<32>>on_miss: FImplementations
impl<EVM, F> JitEvm<EVM, F>
impl<EVM, F> JitEvm<EVM, F>
pub fn with_on_miss(
inner: EVM,
functions: HashMap<FixedBytes<32>, unsafe extern "C" fn(NonNull<EvmContext<'_>>, NonNull<EvmStack>, NonNull<usize>) -> InstructionResult, FbBuildHasher<32>>,
on_miss: F,
) -> JitEvm<EVM, F>
pub fn with_on_miss( inner: EVM, functions: HashMap<FixedBytes<32>, unsafe extern "C" fn(NonNull<EvmContext<'_>>, NonNull<EvmStack>, NonNull<usize>) -> InstructionResult, FbBuildHasher<32>>, on_miss: F, ) -> JitEvm<EVM, F>
Create a new JIT EVM wrapper with a custom miss handler.
pub fn into_inner(self) -> EVM
pub fn into_inner(self) -> EVM
Consumes the wrapper and returns the inner EVM.